@@ -32,15 +32,14 @@ _error_handler_async_local = error_handler_async(
 
 
 class WebSocketAdapter(Adapter):
-    """WebSocket 适配器。作为 WebSocket 客户端与 mirai-api-http 沟通。
-    """
+    """WebSocket 适配器。作为 WebSocket 客户端与 mirai-api-http 沟通。"""
     host_name: str
     """WebSocket Server 的地址。"""
     sync_id: str
     """mirai-api-http 配置的同步 ID。"""
     qq: int
     """机器人的 QQ 号。"""
-    connection: WebSocketClientProtocol
+    connection: Optional[WebSocketClientProtocol]
     """WebSocket 客户端连接。"""
     heartbeat_interval: float
     """每隔多久发送心跳包，单位：秒。"""
@@ -54,17 +53,13 @@ class WebSocketAdapter(Adapter):
         heartbeat_interval: float = 60.,
     ):
         """
-        `verify_key: str` mirai-api-http 配置的认证 key，关闭认证时为 None。
-
-        `host: str` WebSocket Server 的地址。
-
-        `port: int` WebSocket Server 的端口。
-
-        `sync_id: int` mirai-api-http 配置的同步 ID。
-
-        `single_mode: bool = False` 是否启用单例模式。
-
-        `heartbeat_interval: float = 60.` 每隔多久发送心跳包，单位：秒。
+        Args:
+            verify_key: mirai-api-http 配置的认证 key，关闭认证时为 None。
+            host: WebSocket Server 的地址。
+            port: WebSocket Server 的端口。
+            sync_id: mirai-api-http 配置的同步 ID。
+            single_mode: 是否启用单例模式。
+            heartbeat_interval: 每隔多久发送心跳包，单位秒。
         """
         super().__init__(verify_key=verify_key, single_mode=single_mode)
 
@@ -86,6 +81,9 @@ class WebSocketAdapter(Adapter):
         self.sync_id = sync_id  # 这个神奇的 sync_id，默认值 -1，居然是个字符串
         # 既然这样不如把 sync_id 全改成字符串好了
 
+        self.qq = 0
+        self.connection = None
+
         self.heartbeat_interval = heartbeat_interval
 
         # 接收 WebSocket 数据的 Task
@@ -168,16 +166,14 @@ class WebSocketAdapter(Adapter):
                     raise exceptions.ApiError(data)
 
                 return data
-            else:
                 # 如果没有对应同步 ID 的数据，则等待 websocket 数据
                 # 目前存在问题：如果 mah 发回的数据不含 sync_id，
                 # 这里就会无限循环……
                 # 所以还是限制次数好了。
-                await asyncio.sleep(0.1)
-        else:
-            raise TimeoutError(
-                f'[WebSocket] mirai-api-http 响应超时，可能是由于调用出错。同步 ID：{sync_id}。'
-            )
+            await asyncio.sleep(0.1)
+        raise TimeoutError(
+            f'[WebSocket] mirai-api-http 响应超时，可能是由于调用出错。同步 ID：{sync_id}。'
+        )
 
     @_error_handler_async_local
     async def login(self, qq: int):
@@ -214,6 +210,10 @@ class WebSocketAdapter(Adapter):
         self._tasks.create_task(self.emit(event['type'], event))
 
     async def call_api(self, api: str, method: Method = Method.GET, **params):
+        if not self.connection:
+            raise exceptions.NetworkError(
+                f'WebSocket 通道 {self.host_name} 未连接！'
+            )
         self._local_sync_id += 1  # 使用不同的 sync_id
         sync_id = str(self._local_sync_id)
         content = {
