@@ -12,7 +12,7 @@ from typing import (
 )
 
 if TYPE_CHECKING:
-    from typing import Literal
+    from typing_extensions import Literal
 else:
     try:
         from typing import Literal
