@@ -3,10 +3,10 @@
 此模块提供事件模型。
 """
 from datetime import datetime
-from typing import TYPE_CHECKING, Any, Optional, Union
+from typing import TYPE_CHECKING, Any, Optional, Union, cast
 
 if TYPE_CHECKING:
-    from typing import Literal
+    from typing_extensions import Literal
 else:
     try:
         from typing import Literal
@@ -38,6 +38,13 @@ class Event(MiraiIndexedModel):
             )
         ) + ')'
 
+    @classmethod
+    def parse_obj(cls, obj: dict) -> 'Event':
+        try:
+            return cast(Event, super().parse_obj(obj))
+        except ValueError:
+            return Event(type=obj['type'])
+
 
 ###############################
 # Bot Event
